@@ -59,27 +59,39 @@
 #'
 #' # Secondary axes work for date and datetime scales too:
 #' df <- data.frame(
-#'   dx = seq(as.POSIXct("2012-02-29 12:00:00",
-#'                        tz = "UTC",
-#'                        format = "%Y-%m-%d %H:%M:%S"
-#'   ),
-#'   length.out = 10, by = "4 hour"
+#'   dx = seq(
+#'     as.POSIXct("2012-02-29 12:00:00", tz = "UTC"),
+#'     length.out = 10,
+#'     by = "4 hour"
 #'   ),
 #'   price = seq(20, 200000, length.out = 10)
 #'  )
 #'
 #' # This may useful for labelling different time scales in the same plot
-#' ggplot(df, aes(x = dx, y = price)) + geom_line() +
-#'   scale_x_datetime("Date", date_labels = "%b %d",
-#'   date_breaks = "6 hour",
-#'   sec.axis = dup_axis(name = "Time of Day",
-#'   labels = scales::time_format("%I %p")))
+#' ggplot(df, aes(x = dx, y = price)) +
+#'   geom_line() +
+#'   scale_x_datetime(
+#'     "Date",
+#'     date_labels = "%b %d",
+#'     date_breaks = "6 hour",
+#'     sec.axis = dup_axis(
+#'       name = "Time of Day",
+#'       labels = scales::time_format("%I %p")
+#'     )
+#'   )
 #'
 #' # or to transform axes for different timezones
-#' ggplot(df, aes(x = dx, y = price)) + geom_line() +
-#'   scale_x_datetime("GMT", date_labels = "%b %d %I %p",
-#'   sec.axis = sec_axis(~ . + 8 * 3600, name = "GMT+8",
-#'   labels = scales::time_format("%b %d %I %p")))
+#' ggplot(df, aes(x = dx, y = price)) +
+#'   geom_line() +
+#'   scale_x_datetime("
+#'     GMT",
+#'     date_labels = "%b %d %I %p",
+#'     sec.axis = sec_axis(
+#'       ~ . + 8 * 3600,
+#'       name = "GMT+8",
+#'       labels = scales::time_format("%b %d %I %p")
+#'     )
+#'   )
 #'
 #' @export
 sec_axis <- function(trans = NULL, name = waiver(), breaks = waiver(), labels = waiver(),
@@ -201,30 +213,38 @@ AxisSecondary <- ggproto("AxisSecondary", NULL,
       range_info <- temp_scale$break_info()
 
       # Map the break values back to their correct position on the primary scale
-      old_val <- lapply(range_info$major_source, function(x) which.min(abs(full_range - x)))
-      old_val <- old_range[unlist(old_val)]
-      old_val_trans <- scale$trans$transform(old_val)
+      if (!is.null(range_info$major_source)) {
+        old_val <- lapply(range_info$major_source, function(x) which.min(abs(full_range - x)))
+        old_val <- old_range[unlist(old_val)]
+        old_val_trans <- scale$trans$transform(old_val)
 
-      old_val_minor <- lapply(range_info$minor_source, function(x) which.min(abs(full_range - x)))
-      old_val_minor <- old_range[unlist(old_val_minor)]
-      old_val_minor_trans <- scale$trans$transform(old_val_minor)
+        # rescale values from 0 to 1
+        range_info$major[] <- round(
+          rescale(
+            scale$map(old_val_trans, range(old_val_trans)),
+            from = range
+          ),
+          digits = 3
+        )
+      } else {
+        old_val_trans <- NULL
+      }
 
-      # rescale values from 0 to 1
-      range_info$major[] <- round(
-        rescale(
-          scale$map(old_val_trans, range(old_val_trans)),
-          from = range
-        ),
-        digits = 3
-      )
+      if (!is.null(range_info$minor_source)) {
+        old_val_minor <- lapply(range_info$minor_source, function(x) which.min(abs(full_range - x)))
+        old_val_minor <- old_range[unlist(old_val_minor)]
+        old_val_minor_trans <- scale$trans$transform(old_val_minor)
 
-      range_info$minor[] <- round(
-        rescale(
-          scale$map(old_val_minor_trans, range(old_val_minor_trans)),
-          from = range
-        ),
-        digits = 3
-      )
+        range_info$minor[] <- round(
+          rescale(
+            scale$map(old_val_minor_trans, range(old_val_minor_trans)),
+            from = range
+          ),
+          digits = 3
+        )
+      } else {
+        old_val_minor_trans <- NULL
+      }
     }
 
     # The _source values should be in (primary) scale_transformed space,
