@@ -3,7 +3,7 @@
 #' `coord_map()` projects a portion of the earth, which is approximately
 #' spherical, onto a flat 2D plane using any projection defined by the
 #' `mapproj` package. Map projections do not, in general, preserve straight
-#' lines, so this requires considerable computation. `coord_quickmap` is a
+#' lines, so this requires considerable computation. `coord_quickmap()` is a
 #' quick approximation that does preserve straight lines. It works best for
 #' smaller areas closer to the equator.
 #'
@@ -318,6 +318,7 @@ CoordMap <- ggproto("CoordMap", Coord,
 
 
 mproject <- function(coord, x, y, orientation) {
+  check_installed("mapproj", reason = "for `coord_map()`")
   suppressWarnings(mapproj::mapproject(x, y,
     projection = coord$projection,
     parameters  = coord$params,
