@@ -86,6 +86,13 @@ facet_wrap <- function(facets, nrow = NULL, ncol = NULL, scales = "fixed",
     x = any(scales %in% c("free_x", "free")),
     y = any(scales %in% c("free_y", "free"))
   )
+
+  # Check for deprecated labellers
+  labeller <- check_labeller(labeller)
+
+  # Flatten all facets dimensions into a single one
+  facets <- wrap_as_facets_list(facets)
+
   if (!is.null(switch)) {
     .Deprecated("strip.position", old = "switch")
     strip.position <- if (switch == "x") "bottom" else "left"
@@ -102,12 +109,6 @@ facet_wrap <- function(facets, nrow = NULL, ncol = NULL, scales = "fixed",
     ncol <- sanitise_dim(ncol)
   }
 
-  # Check for deprecated labellers
-  labeller <- check_labeller(labeller)
-
-  # Flatten all facets dimensions into a single one
-  facets <- wrap_as_facets_list(facets)
-
   ggproto(NULL, FacetWrap,
     shrink = shrink,
     params = list(
@@ -269,7 +270,7 @@ FacetWrap <- ggproto("FacetWrap", Facet,
     empties <- apply(panel_table, c(1,2), function(x) is.zero(x[[1]]))
     panel_table <- gtable_matrix("layout", panel_table,
      widths = unit(rep(1, ncol), "null"),
-     heights = unit(rep(aspect_ratio, nrow), "null"), respect = respect, clip = coord$clip, z = matrix(1, ncol = ncol, nrow = nrow))
+     heights = unit(rep(abs(aspect_ratio), nrow), "null"), respect = respect, clip = coord$clip, z = matrix(1, ncol = ncol, nrow = nrow))
     panel_table$layout$name <- paste0('panel-', rep(seq_len(ncol), nrow), '-', rep(seq_len(nrow), each = ncol))
 
     panel_table <- gtable_add_col_space(panel_table,
@@ -393,7 +394,7 @@ FacetWrap <- ggproto("FacetWrap", Facet,
 #'
 #' Cleans up the input to be an integer greater than or equal to one, or
 #' `NULL`. Intended to be used on the `nrow` and `ncol`
-#' arguments of `facet_wrap`.
+#' arguments of `facet_wrap()`.
 #' @param n Hopefully an integer greater than or equal to one, or `NULL`,
 #' though other inputs are handled.
 #' @return An integer greater than or equal to one, or `NULL`.
