@@ -11,20 +11,20 @@
 #' @inheritParams layer
 #' @inheritParams geom_point
 #' @param geom,stat Use to override the default connection between
-#'   `geom_bin2d` and `stat_bin2d`.
+#'   `geom_bin_2d()` and `stat_bin_2d()`.
 #' @seealso [stat_binhex()] for hexagonal binning
 #' @examples
 #' d <- ggplot(diamonds, aes(x, y)) + xlim(4, 10) + ylim(4, 10)
-#' d + geom_bin2d()
+#' d + geom_bin_2d()
 #'
 #' # You can control the size of the bins by specifying the number of
 #' # bins in each direction:
-#' d + geom_bin2d(bins = 10)
-#' d + geom_bin2d(bins = 30)
+#' d + geom_bin_2d(bins = 10)
+#' d + geom_bin_2d(bins = 30)
 #'
 #' # Or by specifying the width of the bins
-#' d + geom_bin2d(binwidth = c(0.1, 0.1))
-geom_bin2d <- function(mapping = NULL, data = NULL,
+#' d + geom_bin_2d(binwidth = c(0.1, 0.1))
+geom_bin_2d <- function(mapping = NULL, data = NULL,
                        stat = "bin2d", position = "identity",
                        ...,
                        na.rm = FALSE,
@@ -45,3 +45,9 @@ geom_bin2d <- function(mapping = NULL, data = NULL,
     )
   )
 }
+
+#' @export
+#' @rdname geom_bin_2d
+#' @usage NULL
+geom_bin2d <- geom_bin_2d
+
