@@ -60,8 +60,11 @@
 #' @references Wilkinson, L. (1999) Dot plots. The American Statistician,
 #'    53(3), 276-281.
 #' @examples
-#' ggplot(mtcars, aes(x = mpg)) + geom_dotplot()
-#' ggplot(mtcars, aes(x = mpg)) + geom_dotplot(binwidth = 1.5)
+#' ggplot(mtcars, aes(x = mpg)) +
+#'   geom_dotplot()
+#'
+#' ggplot(mtcars, aes(x = mpg)) +
+#'   geom_dotplot(binwidth = 1.5)
 #'
 #' # Use fixed-width bins
 #' ggplot(mtcars, aes(x = mpg)) +
@@ -70,6 +73,7 @@
 #' # Some other stacking methods
 #' ggplot(mtcars, aes(x = mpg)) +
 #'   geom_dotplot(binwidth = 1.5, stackdir = "center")
+#'
 #' ggplot(mtcars, aes(x = mpg)) +
 #'   geom_dotplot(binwidth = 1.5, stackdir = "centerwhole")
 #'
@@ -78,13 +82,16 @@
 #'   scale_y_continuous(NULL, breaks = NULL)
 #'
 #' # Overlap dots vertically
-#' ggplot(mtcars, aes(x = mpg)) + geom_dotplot(binwidth = 1.5, stackratio = .7)
+#' ggplot(mtcars, aes(x = mpg)) +
+#'   geom_dotplot(binwidth = 1.5, stackratio = .7)
 #'
 #' # Expand dot diameter
-#' ggplot(mtcars, aes(x = mpg)) + geom_dotplot(binwidth = 1.5, dotsize = 1.25)
+#' ggplot(mtcars, aes(x = mpg)) +
+#'   geom_dotplot(binwidth = 1.5, dotsize = 1.25)
 #'
 #' # Change dot fill colour, stroke width
-#' ggplot(mtcars, aes(x = mpg)) + geom_dotplot(binwidth = 1.5, fill = "white", stroke = 2)
+#' ggplot(mtcars, aes(x = mpg)) +
+#'   geom_dotplot(binwidth = 1.5, fill = "white", stroke = 2)
 #'
 #' \donttest{
 #' # Examples with stacking along y axis instead of x
@@ -142,6 +149,7 @@ geom_dotplot <- function(mapping = NULL, data = NULL,
   if (stackgroups && method == "dotdensity" && binpositions == "bygroup")
     message('geom_dotplot called with stackgroups=TRUE and method="dotdensity". You probably want to set binpositions="all"')
 
+  stackdir <- arg_match0(stackdir, c("up", "down", "center", "centerwhole"), "stackdir")
   layer(
     data = data,
     mapping = mapping,
@@ -203,23 +211,27 @@ GeomDotplot <- ggproto("GeomDotplot", Geom,
       stackaxismax <- .5
     }
 
-
     # Fill the bins: at a given x (or y), if count=3, make 3 entries at that x
     data <- data[rep(1:nrow(data), data$count), ]
 
     # Next part will set the position of each dot within each stack
     # If stackgroups=TRUE, split only on x (or y) and panel; if not stacking, also split by group
     plyvars <- params$binaxis %||% "x"
+    stackaxis <- setdiff(c("x", "y"), plyvars)
     plyvars <- c(plyvars, "PANEL")
     if (is.null(params$stackgroups) || !params$stackgroups)
       plyvars <- c(plyvars, "group")
 
+    if (stackaxis == "x") {
+      plyvars <- c(plyvars, "x")
+    }
+
     # Within each x, or x+group, set countidx=1,2,3, and set stackpos according to stack function
     data <- dapply(data, plyvars, function(xx) {
-            xx$countidx <- 1:nrow(xx)
-            xx$stackpos <- stackdots(xx$countidx)
-            xx
-          })
+      xx$countidx <- 1:nrow(xx)
+      xx$stackpos <- stackdots(xx$countidx)
+      xx
+    })
 
 
     # Set the bounding boxes for the dots
