@@ -7,7 +7,7 @@
 #'
 #' `ggplot()` is used to construct the initial plot object,
 #' and is almost always followed by `+` to add component to the
-#' plot. There are three common ways to invoke `ggplot`:
+#' plot. There are three common ways to invoke `ggplot()`:
 #'
 #' * `ggplot(df, aes(x, y, other aesthetics))`
 #' * `ggplot(df)`
@@ -179,6 +179,10 @@ print.ggplot <- function(x, newpage = is.null(vp), vp = NULL, ...) {
     upViewport()
   }
 
+  if (isTRUE(getOption("BrailleR.VI")) && rlang::is_installed("BrailleR")) {
+    print(asNamespace("BrailleR")$VI(x))
+  }
+
   invisible(x)
 }
 #' @rdname print.ggplot
