@@ -23,6 +23,14 @@ test_that("one group per combination of discrete vars", {
   expect_equal(groups(plot), 4)
 })
 
+test_that("no error for aes(groupS)", {
+  df2 <- data_frame(x = df$a, y = df$b, groupS = 1)
+  g <- add_group(df2)
+
+  expect_equal(nrow(g), nrow(df2))
+  expect_equal(names(g), c("x", "y", "groupS", "group"))
+})
+
 test_that("label is not used as a grouping var", {
   plot <- ggplot(df, aes(x, x, label = a)) + geom_point()
   expect_equal(group(plot), rep(NO_GROUP, 4))
