@@ -4,8 +4,8 @@ test_that("stringsAsFactors doesn't affect results", {
     old <- getOption("stringsAsFactors")
     on.exit(options(stringsAsFactors = old), add = TRUE)
 
-    dat.character <- data_frame(x = letters[5:1], y = 1:5, stringsAsFactors = FALSE)
-    dat.factor <- data_frame(x = letters[5:1], y = 1:5, stringsAsFactors = TRUE)
+    dat.character <- data_frame(x = letters[5:1], y = 1:5)
+    dat.factor <- data_frame(x = letters[5:1], y = 1:5)
 
     base <- ggplot(mapping = aes(x, y)) + geom_point()
     xlabels <- function(x) x$layout$panel_params[[1]]$x$get_labels()
