@@ -4,12 +4,12 @@ test_that("accepts width and height params", {
   df <- data_frame(x = c("a", "b"), y = c("a", "b"))
 
   out1 <- layer_data(ggplot(df, aes(x, y)) + geom_tile())
-  expect_equal(out1$xmin, c(0.5, 1.5))
-  expect_equal(out1$xmax, c(1.5, 2.5))
+  expect_equal(out1$xmin, new_mapped_discrete(c(0.5, 1.5)))
+  expect_equal(out1$xmax, new_mapped_discrete(c(1.5, 2.5)))
 
   out2 <- layer_data(ggplot(df, aes(x, y)) + geom_tile(width = 0.5, height = 0.5))
-  expect_equal(out2$xmin, c(0.75, 1.75))
-  expect_equal(out2$xmax, c(1.25, 2.25))
+  expect_equal(out2$xmin, new_mapped_discrete(c(0.75, 1.75)))
+  expect_equal(out2$xmax, new_mapped_discrete(c(1.25, 2.25)))
 })
 
 test_that("accepts width and height aesthetics", {
